@@ -37,6 +37,7 @@ typedef struct {
     HV *anchors;
     HV *shadows;
     int dump_code;
+    int quote_number_strings;
 } perl_yaml_dumper_t;
 
 static SV *
@@ -121,5 +122,5 @@ get_yaml_tag(SV *);
 
 
 int
-append_output(void *, unsigned char *, unsigned int size);
+append_output(void *, unsigned char *, size_t size);
 
